@@ -10,7 +10,7 @@ use base 'POD2::Base';
 use Encode::Locale qw(decode_argv);
 
 use 5.008_005;
-our $VERSION = '5.18.0.1.61';
+our $VERSION = '5.18.0.1.62';
 
 our @EXPORT_OK = qw(print_pod print_pods);
 
@@ -189,8 +189,8 @@ C<<pod_info>> - Выдает хэш с текущими pod файлами в д
 =back
 
 =head1 AUTHOR
- 
-Nikolay Mishin (L<MISHIN|https://metacpan.org/author/MISHIN>)
+
+Nikolay Mishin E<lt>mi@ya.ru<gt>
 
 =head1 CONTRIBUTORS
 
